Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(61)

Unified Diff: remoting/host/chromoting_messages.h

Issue 836183002: Rename sequence_number to timestamp. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/client/software_video_renderer.cc ('k') | remoting/host/client_session.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/chromoting_messages.h
diff --git a/remoting/host/chromoting_messages.h b/remoting/host/chromoting_messages.h
index 477fef95d500cb6523179943c60a14b027dba33a..dd7ef4174cc03d8027a5167ebc1b4dbaca51d838 100644
--- a/remoting/host/chromoting_messages.h
+++ b/remoting/host/chromoting_messages.h
@@ -160,8 +160,8 @@ IPC_STRUCT_BEGIN(SerializedDesktopFrame)
// Time spent in capture. Unit is in milliseconds.
IPC_STRUCT_MEMBER(int64, capture_time_ms)
- // Sequence number supplied by client for performance tracking.
- IPC_STRUCT_MEMBER(int64, client_sequence_number)
+ // Latest event timestamp supplied by the client for performance tracking.
+ IPC_STRUCT_MEMBER(int64, latest_event_timestamp)
// DPI for this frame.
IPC_STRUCT_MEMBER(webrtc::DesktopVector, dpi)
« no previous file with comments | « remoting/client/software_video_renderer.cc ('k') | remoting/host/client_session.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698